@@ -6,11 +6,6 @@
 Examples
 --------
 See the docstrings of the individual classes for examples.
-  .. testsetup::
-    # Change directory to provide relative paths for doctests
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-    >>> datadir = os.path.realpath(os.path.join(filepath, '../../testing/data'))
-    >>> os.chdir(datadir)
 """
 from __future__ import (print_function, division, unicode_literals,
                         absolute_import)
