@@ -1,15 +1,8 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""
-    Change directory to provide relative paths for doctests
-    >>> import os
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-    >>> datadir = os.path.realpath(os.path.join(filepath, '../../testing/data'))
-    >>> os.chdir(datadir)
-
-"""
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 from builtins import range
 
 import os
@@ -23,8 +16,8 @@ import networkx as nx
 
 from ... import logging
 from ...utils.misc import package_check
-from ..base import (BaseInterface, BaseInterfaceInputSpec, traits,
-                    File, TraitedSpec, Directory, isdefined)
+from ..base import (BaseInterface, BaseInterfaceInputSpec, traits, File,
+                    TraitedSpec, Directory, isdefined)
 iflogger = logging.getLogger('interface')
 
 have_cmp = True
@@ -46,8 +39,8 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
     for hemi in ['lh', 'rh']:
-        spath = cmp_config._get_lausanne_parcellation(
-            'Lausanne2008')[parcellation_name]['fs_label_subdir_name'] % hemi
+        spath = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+            parcellation_name]['fs_label_subdir_name'] % hemi
         paths.append(spath)
     for p in paths:
         try:
@@ -129,21 +122,24 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
     log = cmp_config.get_logger()
 
     for out in comp:
-        mris_cmd = 'mris_ca_label %s %s "%s/surf/%s.sphere.reg" "%s" "%s" ' % (subject_id, out[0],
-                                                                               op.join(subjects_dir, subject_id), out[0], cmp_config.get_lausanne_atlas(out[1]), op.join(fs_label_dir, out[2]))
+        mris_cmd = 'mris_ca_label %s %s "%s/surf/%s.sphere.reg" "%s" "%s" ' % (
+            subject_id, out[0], op.join(subjects_dir, subject_id), out[0],
+            cmp_config.get_lausanne_atlas(out[1]),
+            op.join(fs_label_dir, out[2]))
         runCmd(mris_cmd, log)
         iflogger.info('-----------')
 
         annot = '--annotation "%s"' % out[4]
 
-        mri_an_cmd = 'mri_annotation2label --subject %s --hemi %s --outdir "%s" %s' % (subject_id, out[0], op.join(output_dir, out[3]), annot)
+        mri_an_cmd = 'mri_annotation2label --subject %s --hemi %s --outdir "%s" %s' % (
+            subject_id, out[0], op.join(output_dir, out[3]), annot)
         iflogger.info(mri_an_cmd)
         runCmd(mri_an_cmd, log)
         iflogger.info('-----------')
         iflogger.info(os.environ['SUBJECTS_DIR'])
-    # extract cc and unknown to add to tractography mask, we do not want this as a region of interest
-    # in FS 5.0, unknown and corpuscallosum are not available for the 35 scale (why?),
-    # but for the other scales only, take the ones from _60
+        # extract cc and unknown to add to tractography mask, we do not want this as a region of interest
+        # in FS 5.0, unknown and corpuscallosum are not available for the 35 scale (why?),
+        # but for the other scales only, take the ones from _60
         rhun = op.join(output_dir, 'rh.unknown.label')
         lhun = op.join(output_dir, 'lh.unknown.label')
         rhco = op.join(output_dir, 'rh.corpuscallosum.label')
@@ -152,15 +148,21 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
         op.join(output_dir, 'regenerated_rh_60', 'rh.unknown.label'), rhun)
     shutil.copy(
         op.join(output_dir, 'regenerated_lh_60', 'lh.unknown.label'), lhun)
-    shutil.copy(op.join(
-        output_dir, 'regenerated_rh_60', 'rh.corpuscallosum.label'), rhco)
-    shutil.copy(op.join(
-        output_dir, 'regenerated_lh_60', 'lh.corpuscallosum.label'), lhco)
+    shutil.copy(
+        op.join(output_dir, 'regenerated_rh_60', 'rh.corpuscallosum.label'),
+        rhco)
+    shutil.copy(
+        op.join(output_dir, 'regenerated_lh_60', 'lh.corpuscallosum.label'),
+        lhco)
 
-    mri_cmd = """mri_label2vol --label "%s" --label "%s" --label "%s" --label "%s" --temp "%s" --o  "%s" --identity """ % (rhun, lhun, rhco, lhco, op.join(op.join(subjects_dir, subject_id), 'mri', 'orig.mgz'), op.join(fs_label_dir, 'cc_unknown.nii.gz'))
+    mri_cmd = """mri_label2vol --label "%s" --label "%s" --label "%s" --label "%s" --temp "%s" --o  "%s" --identity """ % (
+        rhun, lhun, rhco, lhco,
+        op.join(op.join(subjects_dir, subject_id), 'mri', 'orig.mgz'),
+        op.join(fs_label_dir, 'cc_unknown.nii.gz'))
     runCmd(mri_cmd, log)
     runCmd('mris_volmask %s' % subject_id, log)
-    mri_cmd = 'mri_convert -i "%s/mri/ribbon.mgz" -o "%s/mri/ribbon.nii.gz"' % (op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
+    mri_cmd = 'mri_convert -i "%s/mri/ribbon.mgz" -o "%s/mri/ribbon.nii.gz"' % (
+        op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
     runCmd(mri_cmd, log)
     mri_cmd = 'mri_convert -i "%s/mri/aseg.mgz" -o "%s/mri/aseg.nii.gz"' % (
         op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
@@ -178,8 +180,8 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
     log = cmp_config.get_logger()
-    parval = cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name]
+    parval = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+        parcellation_name]
     pgpath = parval['node_information_graphml']
     aseg = nb.load(op.join(fs_dir, 'mri', 'aseg.nii.gz'))
     asegd = aseg.get_data()
@@ -204,8 +206,9 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
                 dist[x, y, z] = np.sqrt(np.sum(np.multiply(distxyz, distxyz)))
 
     iflogger.info("Working on parcellation: ")
-    iflogger.info(cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name])
+    iflogger.info(
+        cmp_config._get_lausanne_parcellation('Lausanne2008')[
+            parcellation_name])
     iflogger.info("========================")
     pg = nx.read_graphml(pgpath)
     # each node represents a brain region
@@ -240,8 +243,8 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
             iflogger.info('Region %s of %s', count, pg.number_of_nodes())
             iflogger.info('---------------------')
 
-            labelpath = op.join(
-                output_dir, parval['fs_label_subdir_name'] % hemi)
+            labelpath = op.join(output_dir,
+                                parval['fs_label_subdir_name'] % hemi)
             # construct .label file name
 
             fname = '%s.%s.label' % (hemi, brv['dn_fsname'])
@@ -249,8 +252,9 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
             # execute fs mri_label2vol to generate volume roi from the label file
             # store it in temporary file to be overwritten for each region
 
-            mri_cmd = 'mri_label2vol --label "%s" --temp "%s" --o "%s" --identity' % (op.join(labelpath, fname),
-                                                                                      op.join(fs_dir, 'mri', 'orig.mgz'), op.join(output_dir, 'tmp.nii.gz'))
+            mri_cmd = 'mri_label2vol --label "%s" --temp "%s" --o "%s" --identity' % (
+                op.join(labelpath, fname), op.join(fs_dir, 'mri', 'orig.mgz'),
+                op.join(output_dir, 'tmp.nii.gz'))
             runCmd(mri_cmd, log)
 
             tmp = nb.load(op.join(output_dir, 'tmp.nii.gz'))
@@ -306,8 +310,8 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     fs_dir = op.join(subjects_dir, subject_id)
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
-    pgpath = cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name]['node_information_graphml']
+    pgpath = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+        parcellation_name]['node_information_graphml']
     # load ribbon as basis for white matter mask
     fsmask = nb.load(op.join(fs_dir, 'mri', 'ribbon.nii.gz'))
     fsmaskd = fsmask.get_data()
@@ -348,35 +352,21 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
 
     # lateral ventricles, thalamus proper and caudate
     # the latter two removed for better erosion, but put back afterwards
-    idx = np.where((asegd == 4) |
-                   (asegd == 43) |
-                   (asegd == 11) |
-                   (asegd == 50) |
-                   (asegd == 31) |
-                   (asegd == 63) |
-                   (asegd == 10) |
-                   (asegd == 49))
+    idx = np.where((asegd == 4) | (asegd == 43) | (asegd == 11) | (asegd == 50)
+                   | (asegd == 31) | (asegd == 63) | (asegd == 10)
+                   | (asegd == 49))
     csfA[idx] = 1
     csfA = imerode(imerode(csfA, se1), se)
 
     # thalmus proper and cuadate are put back because they are not lateral ventricles
-    idx = np.where((asegd == 11) |
-                   (asegd == 50) |
-                   (asegd == 10) |
-                   (asegd == 49))
+    idx = np.where((asegd == 11) | (asegd == 50) | (asegd == 10)
+                   | (asegd == 49))
     csfA[idx] = 0
 
     # REST CSF, IE 3RD AND 4TH VENTRICULE AND EXTRACEREBRAL CSF
-    idx = np.where((asegd == 5) |
-                   (asegd == 14) |
-                   (asegd == 15) |
-                   (asegd == 24) |
-                   (asegd == 44) |
-                   (asegd == 72) |
-                   (asegd == 75) |
-                   (asegd == 76) |
-                   (asegd == 213) |
-                   (asegd == 221))
+    idx = np.where((asegd == 5) | (asegd == 14) | (asegd == 15) | (asegd == 24)
+                   | (asegd == 44) | (asegd == 72) | (asegd == 75)
+                   | (asegd == 76) | (asegd == 213) | (asegd == 221))
     # 43 ??, 4??  213?, 221?
     # more to discuss.
     for i in [5, 14, 15, 24, 44, 72, 75, 76, 213, 221]:
@@ -411,10 +401,12 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     remaining[idx] = 1
 
     # now remove all the structures from the white matter
-    idx = np.where(
-        (csfA != 0) | (csfB != 0) | (gr_ncl != 0) | (remaining != 0))
+    idx = np.where((csfA != 0) | (csfB != 0) | (gr_ncl != 0)
+                   | (remaining != 0))
     wmmask[idx] = 0
-    iflogger.info("Removing lateral ventricles and eroded grey nuclei and brainstem from white matter mask")
+    iflogger.info(
+        "Removing lateral ventricles and eroded grey nuclei and brainstem from white matter mask"
+    )
 
     # ADD voxels from 'cc_unknown.nii.gz' dataset
     ccun = nb.load(op.join(fs_dir, 'label', 'cc_unknown.nii.gz'))
@@ -444,7 +436,8 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     nb.save(img, wm_out)
 
 
-def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name, out_roi_file, dilation):
+def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name,
+                           out_roi_file, dilation):
     fs_dir = op.join(subjects_dir, subject_id)
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
@@ -452,16 +445,14 @@ def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name,
     output_dir = op.abspath(op.curdir)
 
     iflogger.info('Cropping and moving datasets to %s', output_dir)
-    ds = [
-        (op.join(fs_dir, 'mri', 'aseg.nii.gz'),
-         op.abspath('aseg.nii.gz')),
-        (op.join(fs_dir, 'mri', 'ribbon.nii.gz'),
-         op.abspath('ribbon.nii.gz')),
-        (op.join(fs_dir, 'mri', 'fsmask_1mm.nii.gz'),
-         op.abspath('fsmask_1mm.nii.gz')),
-        (op.join(fs_dir, 'label', 'cc_unknown.nii.gz'),
-         op.abspath('cc_unknown.nii.gz'))
-    ]
+    ds = [(op.join(fs_dir, 'mri', 'aseg.nii.gz'),
+           op.abspath('aseg.nii.gz')), (op.join(fs_dir, 'mri',
+                                                'ribbon.nii.gz'),
+                                        op.abspath('ribbon.nii.gz')),
+          (op.join(fs_dir, 'mri', 'fsmask_1mm.nii.gz'),
+           op.abspath('fsmask_1mm.nii.gz')), (op.join(fs_dir, 'label',
+                                                      'cc_unknown.nii.gz'),
+                                              op.abspath('cc_unknown.nii.gz'))]
 
     ds.append((op.abspath('ROI_%s.nii.gz' % parcellation_name),
                op.abspath('ROI_HR_th.nii.gz')))
@@ -475,8 +466,9 @@ def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name,
             raise Exception('File %s does not exist.' % d[0])
         # reslice to original volume because the roi creation with freesurfer
         # changed to 256x256x256 resolution
-        mri_cmd = 'mri_convert -rl "%s" -rt nearest "%s" -nc "%s"' % (
-            orig, d[0], d[1])
+        mri_cmd = 'mri_convert -rl "%s" -rt nearest "%s" -nc "%s"' % (orig,
+                                                                      d[0],
+                                                                      d[1])
         runCmd(mri_cmd, log)
 
 
@@ -494,12 +486,12 @@ R: the neighbourhood of the specified point in Z
 """
     R = np.ones(shape, dtype=Z.dtype) * \
         fill  # initialize output block to the fill value
-    P = np.array(
-        list(position)).astype(int)  # position coordinates(numpy array)
-    Rs = np.array(
-        list(R.shape)).astype(int)  # output block dimensions (numpy array)
-    Zs = np.array(
-        list(Z.shape)).astype(int)  # original volume dimensions (numpy array)
+    P = np.array(list(position)).astype(
+        int)  # position coordinates(numpy array)
+    Rs = np.array(list(R.shape)).astype(
+        int)  # output block dimensions (numpy array)
+    Zs = np.array(list(Z.shape)).astype(
+        int)  # original volume dimensions (numpy array)
 
     R_start = np.zeros(len(shape)).astype(int)
     R_stop = np.array(list(shape)).astype(int)
@@ -510,40 +502,51 @@ R: the neighbourhood of the specified point in Z
     Z_stop_cor = (np.minimum(Z_stop, Zs)).tolist()  # handle borders
     R_stop = R_stop - (Z_stop - Z_stop_cor)
 
-    R[R_start[0]:R_stop[0], R_start[1]:R_stop[1], R_start[2]:R_stop[2]] = Z[Z_start_cor[0]:Z_stop_cor[0], Z_start_cor[1]:Z_stop_cor[1], Z_start_cor[2]:Z_stop_cor[2]]
+    R[R_start[0]:R_stop[0], R_start[1]:R_stop[1], R_start[2]:R_stop[
+        2]] = Z[Z_start_cor[0]:Z_stop_cor[0], Z_start_cor[1]:Z_stop_cor[1],
+                Z_start_cor[2]:Z_stop_cor[2]]
 
     return R
 
 
 class ParcellateInputSpec(BaseInterfaceInputSpec):
     subject_id = traits.String(mandatory=True, desc='Subject ID')
-    parcellation_name = traits.Enum('scale500', ['scale33', 'scale60', 'scale125', 'scale250', 'scale500'], usedefault=True)
+    parcellation_name = traits.Enum(
+        'scale500', ['scale33', 'scale60', 'scale125', 'scale250', 'scale500'],
+        usedefault=True)
     freesurfer_dir = Directory(exists=True, desc='Freesurfer main directory')
     subjects_dir = Directory(exists=True, desc='Freesurfer subjects directory')
     out_roi_file = File(
         genfile=True, desc='Region of Interest file for connectivity mapping')
-    dilation = traits.Bool(False, usedefault=True,
-                           desc='Dilate cortical parcels? Useful for fMRI connectivity')
+    dilation = traits.Bool(
+        False,
+        usedefault=True,
+        desc='Dilate cortical parcels? Useful for fMRI connectivity')
 
 
 class ParcellateOutputSpec(TraitedSpec):
     roi_file = File(
         exists=True, desc='Region of Interest file for connectivity mapping')
-    roiv_file = File(desc='Region of Interest file for fMRI connectivity mapping')
+    roiv_file = File(
+        desc='Region of Interest file for fMRI connectivity mapping')
     white_matter_mask_file = File(exists=True, desc='White matter mask file')
     cc_unknown_file = File(
         desc='Image file with regions labelled as unknown cortical structures',
         exists=True)
-    ribbon_file = File(desc='Image file detailing the cortical ribbon',
-                       exists=True)
+    ribbon_file = File(
+        desc='Image file detailing the cortical ribbon', exists=True)
     aseg_file = File(
-        desc='Automated segmentation file converted from Freesurfer "subjects" directory',
+        desc=
+        'Automated segmentation file converted from Freesurfer "subjects" directory',
         exists=True)
     roi_file_in_structural_space = File(
-        desc='ROI image resliced to the dimensions of the original structural image',
+        desc=
+        'ROI image resliced to the dimensions of the original structural image',
         exists=True)
     dilated_roi_file_in_structural_space = File(
-        desc='dilated ROI image resliced to the dimensions of the original structural image')
+        desc=
+        'dilated ROI image resliced to the dimensions of the original structural image'
+    )
 
 
 class Parcellate(BaseInterface):
@@ -573,14 +576,24 @@ class Parcellate(BaseInterface):
         if self.inputs.subjects_dir:
             os.environ.update({'SUBJECTS_DIR': self.inputs.subjects_dir})
 
-        if not os.path.exists(op.join(self.inputs.subjects_dir, self.inputs.subject_id)):
+        if not os.path.exists(
+                op.join(self.inputs.subjects_dir, self.inputs.subject_id)):
             raise Exception
         iflogger.info("ROI_HR_th.nii.gz / fsmask_1mm.nii.gz CREATION")
         iflogger.info("=============================================")
-        create_annot_label(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name)
-        create_roi(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name, self.inputs.dilation)
-        create_wm_mask(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name)
-        crop_and_move_datasets(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name, self.inputs.out_roi_file, self.inputs.dilation)
+        create_annot_label(self.inputs.subject_id, self.inputs.subjects_dir,
+                           self.inputs.freesurfer_dir,
+                           self.inputs.parcellation_name)
+        create_roi(self.inputs.subject_id, self.inputs.subjects_dir,
+                   self.inputs.freesurfer_dir, self.inputs.parcellation_name,
+                   self.inputs.dilation)
+        create_wm_mask(self.inputs.subject_id, self.inputs.subjects_dir,
+                       self.inputs.freesurfer_dir,
+                       self.inputs.parcellation_name)
+        crop_and_move_datasets(
+            self.inputs.subject_id, self.inputs.subjects_dir,
+            self.inputs.freesurfer_dir, self.inputs.parcellation_name,
+            self.inputs.out_roi_file, self.inputs.dilation)
         return runtime
 
     def _list_outputs(self):
@@ -591,8 +604,8 @@ class Parcellate(BaseInterface):
             outputs['roi_file'] = op.abspath(
                 self._gen_outfilename('nii.gz', 'ROI'))
         if self.inputs.dilation is True:
-            outputs['roiv_file'] = op.abspath(self._gen_outfilename(
-                'nii.gz', 'ROIv'))
+            outputs['roiv_file'] = op.abspath(
+                self._gen_outfilename('nii.gz', 'ROIv'))
         outputs['white_matter_mask_file'] = op.abspath('fsmask_1mm.nii.gz')
         outputs['cc_unknown_file'] = op.abspath('cc_unknown.nii.gz')
         outputs['ribbon_file'] = op.abspath('ribbon.nii.gz')
