@@ -1,61 +1,62 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""
-   Change directory to provide relative paths for doctests
-   >>> import os
-   >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-   >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
-   >>> os.chdir(datadir)
-"""
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 import os
 
 from .base import TraitedSpec, CommandLineInputSpec, CommandLine, File, isdefined, traits
-from ..external.due import due, Doi, BibTeX
+from ..utils.filemanip import fname_presuffix
+from ..external.due import BibTeX
 
-pvc_methods = ['GTM',
-               'IY',
-               'IY+RL',
-               'IY+VC',
-               'LABBE',
-               'LABBE+MTC',
-               'LABBE+MTC+RL',
-               'LABBE+MTC+VC',
-               'LABBE+RBV',
-               'LABBE+RBV+RL',
-               'LABBE+RBV+VC',
-               'MG',
-               'MG+RL',
-               'MG+VC',
-               'MTC',
-               'MTC+RL',
-               'MTC+VC',
-               'RBV',
-               'RBV+RL',
-               'RBV+VC',
-               'RL',
-               'VC']
+pvc_methods = [
+    'GTM', 'IY', 'IY+RL', 'IY+VC', 'LABBE', 'LABBE+MTC', 'LABBE+MTC+RL',
+    'LABBE+MTC+VC', 'LABBE+RBV', 'LABBE+RBV+RL', 'LABBE+RBV+VC', 'MG', 'MG+RL',
+    'MG+VC', 'MTC', 'MTC+RL', 'MTC+VC', 'RBV', 'RBV+RL', 'RBV+VC', 'RL', 'VC'
+]
 
 
 class PETPVCInputSpec(CommandLineInputSpec):
-    in_file   = File(desc="PET image file", exists=True, mandatory=True, argstr="-i %s")
-    out_file  = File(desc="Output file", genfile=True, hash_files=False, argstr="-o %s")
-    mask_file = File(desc="Mask image file", exists=True, mandatory=True, argstr="-m %s")
-    pvc       = traits.Enum(pvc_methods, desc="Desired PVC method", mandatory=True, argstr="-p %s")
-    fwhm_x    = traits.Float(desc="The full-width at half maximum in mm along x-axis", mandatory=True, argstr="-x %.4f")
-    fwhm_y    = traits.Float(desc="The full-width at half maximum in mm along y-axis", mandatory=True, argstr="-y %.4f")
-    fwhm_z    = traits.Float(desc="The full-width at half maximum in mm along z-axis", mandatory=True, argstr="-z %.4f")
-    debug     = traits.Bool (desc="Prints debug information", usedefault=True, default_value=False, argstr="-d")
-    n_iter    = traits.Int  (desc="Number of iterations", default_value=10, argstr="-n %d")
-    n_deconv  = traits.Int  (desc="Number of deconvolution iterations", default_value=10, argstr="-k %d")
-    alpha     = traits.Float(desc="Alpha value", default_value=1.5, argstr="-a %.4f")
-    stop_crit = traits.Float(desc="Stopping criterion", default_value=0.01, argstr="-a %.4f")
+    in_file = File(
+        desc="PET image file", exists=True, mandatory=True, argstr="-i %s")
+    out_file = File(
+        desc="Output file", genfile=True, hash_files=False, argstr="-o %s")
+    mask_file = File(
+        desc="Mask image file", exists=True, mandatory=True, argstr="-m %s")
+    pvc = traits.Enum(
+        pvc_methods, desc="Desired PVC method", mandatory=True, argstr="-p %s")
+    fwhm_x = traits.Float(
+        desc="The full-width at half maximum in mm along x-axis",
+        mandatory=True,
+        argstr="-x %.4f")
+    fwhm_y = traits.Float(
+        desc="The full-width at half maximum in mm along y-axis",
+        mandatory=True,
+        argstr="-y %.4f")
+    fwhm_z = traits.Float(
+        desc="The full-width at half maximum in mm along z-axis",
+        mandatory=True,
+        argstr="-z %.4f")
+    debug = traits.Bool(
+        desc="Prints debug information",
+        usedefault=True,
+        default_value=False,
+        argstr="-d")
+    n_iter = traits.Int(
+        desc="Number of iterations", default_value=10, argstr="-n %d")
+    n_deconv = traits.Int(
+        desc="Number of deconvolution iterations",
+        default_value=10,
+        argstr="-k %d")
+    alpha = traits.Float(
+        desc="Alpha value", default_value=1.5, argstr="-a %.4f")
+    stop_crit = traits.Float(
+        desc="Stopping criterion", default_value=0.01, argstr="-a %.4f")
 
 
 class PETPVCOutputSpec(TraitedSpec):
-    out_file = File(desc = "Output file")
+    out_file = File(desc="Output file")
 
 
 class PETPVC(CommandLine):
@@ -146,35 +147,43 @@ class PETPVC(CommandLine):
     output_spec = PETPVCOutputSpec
     _cmd = 'petpvc'
 
-    references_ = [{'entry': BibTeX("@article{0031-9155-61-22-7975,"
-                                    "author={Benjamin A Thomas and Vesna Cuplov and Alexandre Bousse and "
-                                             "Adriana Mendes and Kris Thielemans and Brian F Hutton and Kjell Erlandsson},"
-                                    "title={PETPVC: a toolbox for performing partial volume correction "
-                                            "techniques in positron emission tomography},"
-                                    "journal={Physics in Medicine and Biology},"
-                                    "volume={61},"
-                                    "number={22},"
-                                    "pages={7975},"
-                                    "url={http://stacks.iop.org/0031-9155/61/i=22/a=7975},"
-                                    "doi={http://dx.doi.org/10.1088/0031-9155/61/22/7975},"
-                                    "year={2016},"
-                                    "}"),
-                    'description': 'PETPVC software implementation publication',
-                    'tags': ['implementation'],
-                    }]
+    references_ = [{
+        'entry':
+        BibTeX(
+            "@article{0031-9155-61-22-7975,"
+            "author={Benjamin A Thomas and Vesna Cuplov and Alexandre Bousse and "
+            "Adriana Mendes and Kris Thielemans and Brian F Hutton and Kjell Erlandsson},"
+            "title={PETPVC: a toolbox for performing partial volume correction "
+            "techniques in positron emission tomography},"
+            "journal={Physics in Medicine and Biology},"
+            "volume={61},"
+            "number={22},"
+            "pages={7975},"
+            "url={http://stacks.iop.org/0031-9155/61/i=22/a=7975},"
+            "doi={http://dx.doi.org/10.1088/0031-9155/61/22/7975},"
+            "year={2016},"
+            "}"),
+        'description':
+        'PETPVC software implementation publication',
+        'tags': ['implementation'],
+    }]
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
         outputs['out_file'] = self.inputs.out_file
         if not isdefined(outputs['out_file']):
             method_name = self.inputs.pvc.lower()
-            outputs['out_file'] = self._gen_fname(self.inputs.in_file,
-                                                  suffix='_{}_pvc'.format(method_name))
+            outputs['out_file'] = self._gen_fname(
+                self.inputs.in_file, suffix='_{}_pvc'.format(method_name))
 
         outputs['out_file'] = os.path.abspath(outputs['out_file'])
         return outputs
 
-    def _gen_fname(self, basename, cwd=None, suffix=None, change_ext=True,
+    def _gen_fname(self,
+                   basename,
+                   cwd=None,
+                   suffix=None,
+                   change_ext=True,
                    ext='.nii.gz'):
         """Generate a filename based on the given parameters.
 
@@ -200,8 +209,6 @@ class PETPVC(CommandLine):
             New filename based on given parameters.
 
         """
-        from nipype.utils.filemanip import fname_presuffix
-
         if basename == '':
             msg = 'Unable to generate filename for command %s. ' % self.cmd
             msg += 'basename is not set!'
@@ -215,8 +222,8 @@ class PETPVC(CommandLine):
                 suffix = ext
         if suffix is None:
             suffix = ''
-        fname = fname_presuffix(basename, suffix=suffix,
-                                use_ext=False, newpath=cwd)
+        fname = fname_presuffix(
+            basename, suffix=suffix, use_ext=False, newpath=cwd)
         return fname
 
     def _gen_filename(self, name):
